View Source Ueberauth.Strategy.Patreon (ueberauth_patreon v1.0.0)

Link to this section Summary

Functions

Includes the credentials from the Patreon response.

Stores the raw information (including the token) obtained from the Patreon callback.

Cleans up the private area of the connection used for passing the raw Notion response around during the callback.

Handles the initial redirect to the patreon authentication page.

Fetches the fields to populate the info section of the Ueberauth.Auth struct.

Fetches the uid field from the Twitch response. This defaults to the option uid_field which in-turn defaults to id

Link to this section Functions

Includes the credentials from the Patreon response.

Stores the raw information (including the token) obtained from the Patreon callback.

Cleans up the private area of the connection used for passing the raw Notion response around during the callback.

Handles the initial redirect to the patreon authentication page.

To customize the scope (permissions) that are requested by patreon include them as part of your url:

"https://www.patreon.com/oauth2/authorize"

Fetches the fields to populate the info section of the Ueberauth.Auth struct.

Fetches the uid field from the Twitch response. This defaults to the option uid_field which in-turn defaults to id